package com.inspect.metadata.bdconfig.service;

import com.inspect.metadata.bdconfig.domain.BasedataBdConfigDeviceConvert;

import java.util.List;

public interface IBasedataBdConfigDeviceConvertService {
    BasedataBdConfigDeviceConvert selectBasedataBdConfigDeviceConvertByDeviceConvertId(Long convertId);

    List<BasedataBdConfigDeviceConvert> selectBasedataBdConfigDeviceConvertList(BasedataBdConfigDeviceConvert convert);

    int insertBasedataBdConfigDeviceConvert(BasedataBdConfigDeviceConvert convert);

    int updateBasedataBdConfigDeviceConvert(BasedataBdConfigDeviceConvert convert);

    int deleteBasedataBdConfigDeviceConvertByDeviceConvertIds(Long[] convertIds);

    int deleteBasedataBdConfigDeviceConvertByDeviceConvertId(Long convertId);
}
